import fs from 'node:fs';
import path from 'node:path';
// @ts-expect-error
import barbe from 'barbe';
import { isTest } from '@terascope/utils';
const MAX_RETRIES = isTest ? 2 : 3;
const RETRY_DELAY = isTest ? 50 : 1000; // time in ms
const resourcePath = path.join(process.cwd(), './packages/teraslice/src/lib/cluster/services/cluster/backends/kubernetes/');
export function makeTemplate(folder, fileName) {
    const filePath = path.join(resourcePath, folder, `${fileName}.hbs`);
    const templateData = fs.readFileSync(filePath, 'utf-8');
    const templateKeys = ['{{', '}}'];
    return (config) => {
        const templated = barbe(templateData, templateKeys, config);
        return JSON.parse(templated);
    };
}
// Convert bytes to MB and reduce by 10%
export function getMaxOldSpace(memory) {
    return Math.round(0.9 * (memory / 1024 / 1024));
}
export function setMaxOldSpaceViaEnv(envArr, jobEnv, memory) {
    const envObj = {};
    if (memory && memory > -1) {
        // Set NODE_OPTIONS to override max-old-space-size
        const maxOldSpace = getMaxOldSpace(memory);
        envObj.NODE_OPTIONS = `--max-old-space-size=${maxOldSpace}`;
    }
    Object.assign(envObj, jobEnv);
    Object.entries(envObj).forEach(([name, value]) => {
        envArr.push({
            name,
            value
        });
    });
}
export function getRetryConfig() {
    return {
        retries: MAX_RETRIES,
        delay: RETRY_DELAY
    };
}
//# sourceMappingURL=utils.js.map