import { NativeClustering } from './backends/native/index.js';
import { KubernetesClusterBackend } from './backends/kubernetes/index.js';
import { KubernetesClusterBackendV2 } from './backends/kubernetesV2/index.js';
export function makeClustering(context, { clusterMasterServer }) {
    const clusterType = context.sysconfig.teraslice.cluster_manager_type;
    if (clusterType === 'native') {
        return new NativeClustering(context, clusterMasterServer);
    }
    if (clusterType === 'kubernetes') {
        return new KubernetesClusterBackend(context, clusterMasterServer);
    }
    if (clusterType === 'kubernetesV2') {
        return new KubernetesClusterBackendV2(context, clusterMasterServer);
    }
    throw new Error(`unknown cluster service ${clusterType}, cannot find cluster module`);
}
//# sourceMappingURL=index.js.map